"use strict";
// 1. Load and read documents
// 1. Load schema
// 1. Loop through every type and create a map of `Type.field`
// 1. Go field by field both in operations and fragments
// 1. Check the object type
// 1. Check the resolve type
// 1. Save `Parent.resolve` record (with a source) in the previously created map
// 1. Make some stats out of it
Object.defineProperty(exports, "__esModule", { value: true });
var graphql_1 = require("graphql");
var document_1 = require("../ast/document");
var graphql_2 = require("../utils/graphql");
function coverage(schema, sources) {
    var coverage = {};
    var typeMap = schema.getTypeMap();
    var typeInfo = new graphql_1.TypeInfo(schema);
    var visitor = {
        Field: function () {
            var fieldDef = typeInfo.getFieldDef();
            var parent = typeInfo.getParentType();
            if (parent && fieldDef) {
                coverage[parent.name].hits++;
                coverage[parent.name].children[fieldDef.name].hits++;
            }
        },
    };
    for (var typename in typeMap) {
        if (!graphql_2.isForIntrospection(typename) && !graphql_2.isPrimitive(typename)) {
            var type = typeMap[typename];
            if (graphql_1.isObjectType(type)) {
                var typeCoverage = {
                    hits: 0,
                    type: type,
                    children: {},
                };
                var fieldMap = type.getFields();
                for (var fieldname in fieldMap) {
                    var field = fieldMap[fieldname];
                    typeCoverage.children[field.name] = {
                        hits: 0,
                    };
                }
                coverage[type.name] = typeCoverage;
            }
        }
    }
    var documents = sources.map(document_1.readDocument);
    documents.forEach(function (doc) {
        doc.operations.forEach(function (op) {
            graphql_1.visit(op.node, graphql_1.visitWithTypeInfo(typeInfo, visitor));
        });
        doc.fragments.forEach(function (fr) {
            graphql_1.visit(fr.node, graphql_1.visitWithTypeInfo(typeInfo, visitor));
        });
    });
    return coverage;
}
exports.coverage = coverage;
//# sourceMappingURL=index.js.map